/*----------------------------------------------------------------------------
 * Name:    Joystick_LPC15xx.c
 * Purpose: low level Joystick functions
 * Note(s):
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2009-2014 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/
 
#include <LPC15xx.h>                         /* LPC15xx definitions           */
#include "Joystick.h"                        

#define  JOY_ALL   (JOY_UP | JOY_LEFT | JOY_DOWN | JOY_RIGHT | JOY_CENTER)


/*-----------------------------------------------------------------------------
 *       Joystick_Init:  Initialize joystick
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
void Joystick_Initialize (void) {

  LPC_SYSCON->SYSAHBCLKCTRL0 |= (1UL << 16);   /* enable clock for GPIO2 port */

  /* configure GPIO as intput */
  LPC_GPIO_PORT->DIR[2]  &= ~(JOY_ALL);
}

/*-----------------------------------------------------------------------------
 *       Joystick_Uninitialize:  Uninitialize joystick
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
void Joystick_Uninitialize (void) {
  LPC_SYSCON->SYSAHBCLKCTRL0 &= ~(1UL << 16);  /* disable clock for GPIO2 port */

  /* configure GPIO as outtput */
  LPC_GPIO_PORT->DIR[2]  |= (JOY_ALL);

}


/*-----------------------------------------------------------------------------
 *       Joystick_GetButtons:  Get joystick direction keys state
 *
 * Parameters: (none)
 * Return:     joystick directions bitmask
 *----------------------------------------------------------------------------*/
uint32_t Joystick_GetButtons (void) {
  /* Read board keyboard inputs                                               */

  return (LPC_GPIO_PORT->PIN[2] & JOY_ALL);
}
